==> coorrency-8.x-1.0.tar.gz: coorrency/src/Form/CoorrencyBlockForm.php <==
<?php

namespace Drupal\coorrency\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Coorrency block form
 */
class CoorrencyBlockForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'coorrency_block_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['amount'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Amount'),
    ];

    $form['from'] = [
      '#type' => 'select',
      '#title' => $this->t('From'),
      '#options' => $this->_coorrency_get_currencies(),
      '#required' => TRUE,
      '#attached' => [
        'library' => [
          'coorrency/coorrency'
        ],
      ],
    ];

    $form['to'] = [
      '#type' => 'select',
      '#title' => $this->t('To'),
      '#options' => $this->_coorrency_get_currencies(),
      '#required' => TRUE,
    ];

    // Submit.
    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Convert'),
    ];

    $form['coorrency'] = [
      '#type' => 'html_tag',
      '#tag' => 'div',
      '#attributes' => [
        'id' => ['coorrency-rate'],
      ],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $form_state->setRedirect(
      'coorrency.convert',
      [
        'from' => $form_state->getValue('from'),
        'to' => $form_state->getValue('to'),
      ]
    );
  }

  protected function _coorrency_get_currencies() {
    return [
      'AFN' => 'Afghanistan - AFN',
      'EUR' => 'Akrotiri and Dhekelia (UK) - EUR',
      'EUR' => 'Aland Islands (Finland) - EUR',
      'ALL' => 'Albania - ALL',
      'DZD' => 'Algeria - DZD',
      'USD' => 'American Samoa (USA) - USD',
      'EUR' => 'Andorra - EUR',
      'AOA' => 'Angola - AOA',
      'XCD' => 'Anguilla (UK) - XCD',
      'XCD' => 'Antigua and Barbuda - XCD',
      'ARS' => 'Argentina - ARS',
      'AMD' => 'Armenia - AMD',
      'AWG' => 'Aruba (Netherlands) - AWG',
      'SHP' => 'Ascension Island (UK) - SHP',
      'AUD' => 'Australia - AUD',
      'EUR' => 'Austria - EUR',
      'AZN' => 'Azerbaijan - AZN',
      'BSD' => 'Bahamas - BSD',
      'BHD' => 'Bahrain - BHD',
      'BDT' => 'Bangladesh - BDT',
      'BBD' => 'Barbados - BBD',
      'BYN' => 'Belarus - BYN',
      'EUR' => 'Belgium - EUR',
      'BZD' => 'Belize - BZD',
      'XOF' => 'Benin - XOF',
      'BMD' => 'Bermuda (UK) - BMD',
      'BTN' => 'Bhutan - BTN',
      'BOB' => 'Bolivia - BOB',
      'USD' => 'Bonaire (Netherlands) - USD',
      'BAM' => 'Bosnia and Herzegovina - BAM',
      'BWP' => 'Botswana - BWP',
      'BRL' => 'Brazil - BRL',
      'USD' => 'British Indian Ocean Territory (UK) - USD',
      'USD' => 'British Virgin Islands (UK) - USD',
      'BND' => 'Brunei - BND',
      'BGN' => 'Bulgaria - BGN',
      'XOF' => 'Burkina Faso - XOF',
      'BIF' => 'Burundi - BIF',
      'CVE' => 'Cabo Verde - CVE',
      'KHR' => 'Cambodia - KHR',
      'XAF' => 'Cameroon - XAF',
      'CAD' => 'Canada - CAD',
      'USD' => 'Caribbean Netherlands (Netherlands) - USD',
      'KYD' => 'Cayman Islands (UK) - KYD',
      'XAF' => 'Central African Republic - XAF',
      'XAF' => 'Chad - XAF',
      'NZD' => 'Chatham Islands (New Zealand) - NZD',
      'CLP' => 'Chile - CLP',
      'CNY' => 'China - CNY',
      'AUD' => 'Christmas Island (Australia) - AUD',
      'AUD' => 'Cocos (Keeling) Islands (Australia) - AUD',
      'COP' => 'Colombia - COP',
      'KMF' => 'Comoros - KMF',
      'CDF' => 'Congo, Democratic Republic of the - CDF',
      'XAF' => 'Congo, Republic of the - XAF',
      'CRC' => 'Costa Rica - CRC',
      'XOF' => 'Cote d\'Ivoire - XOF',
      'HRK' => 'Croatia - HRK',
      'CUP' => 'Cuba - CUP',
      'ANG' => 'Curacao (Netherlands) - ANG',
      'EUR' => 'Cyprus - EUR',
      'CZK' => 'Czech Republic - CZK',
      'DKK' => 'Denmark - DKK',
      'DJF' => 'Djibouti - DJF',
      'XCD' => 'Dominica - XCD',
      'DOP' => 'Dominican Republic - DOP',
      'USD' => 'Ecuador - USD',
      'EGP' => 'Egypt - EGP',
      'USD' => 'El Salvador - USD',
      'XAF' => 'Equatorial Guinea - XAF',
      'ERN' => 'Eritrea - ERN',
      'EUR' => 'Estonia - EUR',
      'ETB' => 'Ethiopia - ETB',
      'FKP' => 'Falkland Islands (UK) - FKP',
      'DKK' => 'Faroe Islands (Denmark) - DKK',
      'FJD' => 'Fiji - FJD',
      'EUR' => 'Finland - EUR',
      'EUR' => 'France - EUR',
      'EUR' => 'French Guiana (France) - EUR',
      'XPF' => 'French Polynesia (France) - XPF',
      'XAF' => 'Gabon - XAF',
      'GMD' => 'Gambia - GMD',
      'GEL' => 'Georgia - GEL',
      'EUR' => 'Germany - EUR',
      'GHS' => 'Ghana - GHS',
      'GIP' => 'Gibraltar (UK) - GIP',
      'EUR' => 'Greece - EUR',
      'DKK' => 'Greenland (Denmark) - DKK',
      'XCD' => 'Grenada - XCD',
      'EUR' => 'Guadeloupe (France) - EUR',
      'USD' => 'Guam (USA) - USD',
      'GTQ' => 'Guatemala - GTQ',
      'GGP' => 'Guernsey (UK) - GGP',
      'GNF' => 'Guinea - GNF',
      'XOF' => 'Guinea-Bissau - XOF',
      'GYD' => 'Guyana - GYD',
      'HTG' => 'Haiti - HTG',
      'HNL' => 'Honduras - HNL',
      'HKD' => 'Hong Kong (China) - HKD',
      'HUF' => 'Hungary - HUF',
      'ISK' => 'Iceland - ISK',
      'INR' => 'India - INR',
      'IDR' => 'Indonesia - IDR',
      'XDR' => 'International Monetary Fund (IMF) - XDR',
      'IRR' => 'Iran - IRR',
      'IQD' => 'Iraq - IQD',
      'EUR' => 'Ireland - EUR',
      'IMP' => 'Isle of Man (UK) - IMP',
      'ILS' => 'Israel - ILS',
      'EUR' => 'Italy - EUR',
      'JMD' => 'Jamaica - JMD',
      'JPY' => 'Japan - JPY',
      'JEP' => 'Jersey (UK) - JEP',
      'JOD' => 'Jordan - JOD',
      'KZT' => 'Kazakhstan - KZT',
      'KES' => 'Kenya - KES',
      'AUD' => 'Kiribati - AUD',
      'EUR' => 'Kosovo - EUR',
      'KWD' => 'Kuwait - KWD',
      'KGS' => 'Kyrgyzstan - KGS',
      'LAK' => 'Laos - LAK',
      'EUR' => 'Latvia - EUR',
      'LBP' => 'Lebanon - LBP',
      'LSL' => 'Lesotho - LSL',
      'LRD' => 'Liberia - LRD',
      'LYD' => 'Libya - LYD',
      'CHF' => 'Liechtenstein - CHF',
      'EUR' => 'Lithuania - EUR',
      'EUR' => 'Luxembourg - EUR',
      'MOP' => 'Macau (China) - MOP',
      'MKD' => 'Macedonia (FYROM) - MKD',
      'MGA' => 'Madagascar - MGA',
      'MWK' => 'Malawi - MWK',
      'MYR' => 'Malaysia - MYR',
      'MVR' => 'Maldives - MVR',
      'XOF' => 'Mali - XOF',
      'EUR' => 'Malta - EUR',
      'USD' => 'Marshall Islands - USD',
      'EUR' => 'Martinique (France) - EUR',
      'MRO' => 'Mauritania - MRO',
      'MUR' => 'Mauritius - MUR',
      'EUR' => 'Mayotte (France) - EUR',
      'MXN' => 'Mexico - MXN',
      'USD' => 'Micronesia - USD',
      'MDL' => 'Moldova - MDL',
      'EUR' => 'Monaco - EUR',
      'MNT' => 'Mongolia - MNT',
      'EUR' => 'Montenegro - EUR',
      'XCD' => 'Montserrat (UK) - XCD',
      'MAD' => 'Morocco - MAD',
      'MZN' => 'Mozambique - MZN',
      'MMK' => 'Myanmar (Burma) - MMK',
      'NAD' => 'Namibia - NAD',
      'AUD' => 'Nauru - AUD',
      'NPR' => 'Nepal - NPR',
      'EUR' => 'Netherlands - EUR',
      'XPF' => 'New Caledonia (France) - XPF',
      'NZD' => 'New Zealand - NZD',
      'NIO' => 'Nicaragua - NIO',
      'XOF' => 'Niger - XOF',
      'NGN' => 'Nigeria - NGN',
      'NZD' => 'Niue (New Zealand) - NZD',
      'AUD' => 'Norfolk Island (Australia) - AUD',
      'USD' => 'Northern Mariana Islands (USA) - USD',
      'KPW' => 'North Korea - KPW',
      'NOK' => 'Norway - NOK',
      'OMR' => 'Oman - OMR',
      'PKR' => 'Pakistan - PKR',
      'USD' => 'Palau - USD',
      'ILS' => 'Palestine - ILS',
      'USD' => 'Panama - USD',
      'PGK' => 'Papua New Guinea - PGK',
      'PYG' => 'Paraguay - PYG',
      'PEN' => 'Peru - PEN',
      'PHP' => 'Philippines - PHP',
      'NZD' => 'Pitcairn Islands (UK) - NZD',
      'PLN' => 'Poland - PLN',
      'EUR' => 'Portugal - EUR',
      'USD' => 'Puerto Rico (USA) - USD',
      'QAR' => 'Qatar - QAR',
      'EUR' => 'Reunion (France) - EUR',
      'RON' => 'Romania - RON',
      'RUB' => 'Russia - RUB',
      'RWF' => 'Rwanda - RWF',
      'USD' => 'Saba (Netherlands) - USD',
      'EUR' => 'Saint Barthelemy (France) - EUR',
      'SHP' => 'Saint Helena (UK) - SHP',
      'XCD' => 'Saint Kitts and Nevis - XCD',
      'XCD' => 'Saint Lucia - XCD',
      'EUR' => 'Saint Martin (France) - EUR',
      'EUR' => 'Saint Pierre and Miquelon (France) - EUR',
      'XCD' => 'Saint Vincent and the Grenadines - XCD',
      'WST' => 'Samoa - WST',
      'EUR' => 'San Marino - EUR',
      'STD' => 'Sao Tome and Principe - STD',
      'SAR' => 'Saudi Arabia - SAR',
      'XOF' => 'Senegal - XOF',
      'RSD' => 'Serbia - RSD',
      'SCR' => 'Seychelles - SCR',
      'SLL' => 'Sierra Leone - SLL',
      'SGD' => 'Singapore - SGD',
      'USD' => 'Sint Eustatius (Netherlands) - USD',
      'ANG' => 'Sint Maarten (Netherlands) - ANG',
      'EUR' => 'Slovakia - EUR',
      'EUR' => 'Slovenia - EUR',
      'SBD' => 'Solomon Islands - SBD',
      'SOS' => 'Somalia - SOS',
      'ZAR' => 'South Africa - ZAR',
      'GBP' => 'South Georgia Island (UK) - GBP',
      'KRW' => 'South Korea - KRW',
      'SSP' => 'South Sudan - SSP',
      'EUR' => 'Spain - EUR',
      'LKR' => 'Sri Lanka - LKR',
      'SDG' => 'Sudan - SDG',
      'SRD' => 'Suriname - SRD',
      'NOK' => 'Svalbard and Jan Mayen (Norway) - NOK',
      'SZL' => 'Swaziland - SZL',
      'SEK' => 'Sweden - SEK',
      'CHF' => 'Switzerland - CHF',
      'SYP' => 'Syria - SYP',
      'TWD' => 'Taiwan - TWD',
      'TJS' => 'Tajikistan - TJS',
      'TZS' => 'Tanzania - TZS',
      'THB' => 'Thailand - THB',
      'USD' => 'Timor-Leste - USD',
      'XOF' => 'Togo - XOF',
      'NZD' => 'Tokelau (New Zealand) - NZD',
      'TOP' => 'Tonga - TOP',
      'TTD' => 'Trinidad and Tobago - TTD',
      'GBP' => 'Tristan da Cunha (UK) - GBP',
      'TND' => 'Tunisia - TND',
      'TRY' => 'Turkey - TRY',
      'TMT' => 'Turkmenistan - TMT',
      'USD' => 'Turks and Caicos Islands (UK) - USD',
      'AUD' => 'Tuvalu - AUD',
      'UGX' => 'Uganda - UGX',
      'UAH' => 'Ukraine - UAH',
      'AED' => 'United Arab Emirates - AED',
      'GBP' => 'United Kingdom - GBP',
      'USD' => 'United States of America - USD',
      'UYU' => 'Uruguay - UYU',
      'USD' => 'US Virgin Islands (USA) - USD',
      'UZS' => 'Uzbekistan - UZS',
      'VUV' => 'Vanuatu - VUV',
      'EUR' => 'Vatican City (Holy See) - EUR',
      'VEF' => 'Venezuela - VEF',
      'VND' => 'Vietnam - VND',
      'USD' => 'Wake Island (USA) - USD',
      'XPF' => 'Wallis and Futuna (France) - XPF',
      'YER' => 'Yemen - YER',
      'ZMW' => 'Zambia - ZMW',
    ];
  }
}

==> coorrency-8.x-1.1.tar.gz: coorrency/src/Form/CoorrencyBlockForm.php <==
<?php

namespace Drupal\coorrency\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Coorrency block form.
 */
class CoorrencyBlockForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'coorrency_block_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['amount'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Amount'),
    ];

    $form['from'] = [
      '#type' => 'select',
      '#title' => $this->t('From'),
      '#options' => $this->_coorrency_get_currencies(),
      '#required' => TRUE,
      '#attached' => [
        'library' => [
          'coorrency/coorrency',
        ],
      ],
    ];

    $form['to'] = [
      '#type' => 'select',
      '#title' => $this->t('To'),
      '#options' => $this->_coorrency_get_currencies(),
      '#required' => TRUE,
    ];

    // Submit.
    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Convert'),
    ];

    $form['coorrency'] = [
      '#type' => 'html_tag',
      '#tag' => 'div',
      '#attributes' => [
        'id' => ['coorrency-rate'],
      ],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $form_state->setRedirect(
      'coorrency.convert',
      [
        'from' => $form_state->getValue('from'),
        'to' => $form_state->getValue('to'),
      ]
    );
  }

  /**
   * Function to gather all the available currencies.
   */
  protected function _coorrency_get_currencies() {
    return [
      'AFN' => 'Afghanistan - AFN',
      'EUR' => 'Akrotiri and Dhekelia (UK) - EUR',
      'EUR' => 'Aland Islands (Finland) - EUR',
      'ALL' => 'Albania - ALL',
      'DZD' => 'Algeria - DZD',
      'USD' => 'American Samoa (USA) - USD',
      'EUR' => 'Andorra - EUR',
      'AOA' => 'Angola - AOA',
      'XCD' => 'Anguilla (UK) - XCD',
      'XCD' => 'Antigua and Barbuda - XCD',
      'ARS' => 'Argentina - ARS',
      'AMD' => 'Armenia - AMD',
      'AWG' => 'Aruba (Netherlands) - AWG',
      'SHP' => 'Ascension Island (UK) - SHP',
      'AUD' => 'Australia - AUD',
      'EUR' => 'Austria - EUR',
      'AZN' => 'Azerbaijan - AZN',
      'BSD' => 'Bahamas - BSD',
      'BHD' => 'Bahrain - BHD',
      'BDT' => 'Bangladesh - BDT',
      'BBD' => 'Barbados - BBD',
      'BYN' => 'Belarus - BYN',
      'EUR' => 'Belgium - EUR',
      'BZD' => 'Belize - BZD',
      'XOF' => 'Benin - XOF',
      'BMD' => 'Bermuda (UK) - BMD',
      'BTN' => 'Bhutan - BTN',
      'BOB' => 'Bolivia - BOB',
      'USD' => 'Bonaire (Netherlands) - USD',
      'BAM' => 'Bosnia and Herzegovina - BAM',
      'BWP' => 'Botswana - BWP',
      'BRL' => 'Brazil - BRL',
      'USD' => 'British Indian Ocean Territory (UK) - USD',
      'USD' => 'British Virgin Islands (UK) - USD',
      'BND' => 'Brunei - BND',
      'BGN' => 'Bulgaria - BGN',
      'XOF' => 'Burkina Faso - XOF',
      'BIF' => 'Burundi - BIF',
      'CVE' => 'Cabo Verde - CVE',
      'KHR' => 'Cambodia - KHR',
      'XAF' => 'Cameroon - XAF',
      'CAD' => 'Canada - CAD',
      'USD' => 'Caribbean Netherlands (Netherlands) - USD',
      'KYD' => 'Cayman Islands (UK) - KYD',
      'XAF' => 'Central African Republic - XAF',
      'XAF' => 'Chad - XAF',
      'NZD' => 'Chatham Islands (New Zealand) - NZD',
      'CLP' => 'Chile - CLP',
      'CNY' => 'China - CNY',
      'AUD' => 'Christmas Island (Australia) - AUD',
      'AUD' => 'Cocos (Keeling) Islands (Australia) - AUD',
      'COP' => 'Colombia - COP',
      'KMF' => 'Comoros - KMF',
      'CDF' => 'Congo, Democratic Republic of the - CDF',
      'XAF' => 'Congo, Republic of the - XAF',
      'CRC' => 'Costa Rica - CRC',
      'XOF' => 'Cote d\'Ivoire - XOF',
      'HRK' => 'Croatia - HRK',
      'CUP' => 'Cuba - CUP',
      'ANG' => 'Curacao (Netherlands) - ANG',
      'EUR' => 'Cyprus - EUR',
      'CZK' => 'Czech Republic - CZK',
      'DKK' => 'Denmark - DKK',
      'DJF' => 'Djibouti - DJF',
      'XCD' => 'Dominica - XCD',
      'DOP' => 'Dominican Republic - DOP',
      'USD' => 'Ecuador - USD',
      'EGP' => 'Egypt - EGP',
      'USD' => 'El Salvador - USD',
      'XAF' => 'Equatorial Guinea - XAF',
      'ERN' => 'Eritrea - ERN',
      'EUR' => 'Estonia - EUR',
      'ETB' => 'Ethiopia - ETB',
      'FKP' => 'Falkland Islands (UK) - FKP',
      'DKK' => 'Faroe Islands (Denmark) - DKK',
      'FJD' => 'Fiji - FJD',
      'EUR' => 'Finland - EUR',
      'EUR' => 'France - EUR',
      'EUR' => 'French Guiana (France) - EUR',
      'XPF' => 'French Polynesia (France) - XPF',
      'XAF' => 'Gabon - XAF',
      'GMD' => 'Gambia - GMD',
      'GEL' => 'Georgia - GEL',
      'EUR' => 'Germany - EUR',
      'GHS' => 'Ghana - GHS',
      'GIP' => 'Gibraltar (UK) - GIP',
      'EUR' => 'Greece - EUR',
      'DKK' => 'Greenland (Denmark) - DKK',
      'XCD' => 'Grenada - XCD',
      'EUR' => 'Guadeloupe (France) - EUR',
      'USD' => 'Guam (USA) - USD',
      'GTQ' => 'Guatemala - GTQ',
      'GGP' => 'Guernsey (UK) - GGP',
      'GNF' => 'Guinea - GNF',
      'XOF' => 'Guinea-Bissau - XOF',
      'GYD' => 'Guyana - GYD',
      'HTG' => 'Haiti - HTG',
      'HNL' => 'Honduras - HNL',
      'HKD' => 'Hong Kong (China) - HKD',
      'HUF' => 'Hungary - HUF',
      'ISK' => 'Iceland - ISK',
      'INR' => 'India - INR',
      'IDR' => 'Indonesia - IDR',
      'XDR' => 'International Monetary Fund (IMF) - XDR',
      'IRR' => 'Iran - IRR',
      'IQD' => 'Iraq - IQD',
      'EUR' => 'Ireland - EUR',
      'IMP' => 'Isle of Man (UK) - IMP',
      'ILS' => 'Israel - ILS',
      'EUR' => 'Italy - EUR',
      'JMD' => 'Jamaica - JMD',
      'JPY' => 'Japan - JPY',
      'JEP' => 'Jersey (UK) - JEP',
      'JOD' => 'Jordan - JOD',
      'KZT' => 'Kazakhstan - KZT',
      'KES' => 'Kenya - KES',
      'AUD' => 'Kiribati - AUD',
      'EUR' => 'Kosovo - EUR',
      'KWD' => 'Kuwait - KWD',
      'KGS' => 'Kyrgyzstan - KGS',
      'LAK' => 'Laos - LAK',
      'EUR' => 'Latvia - EUR',
      'LBP' => 'Lebanon - LBP',
      'LSL' => 'Lesotho - LSL',
      'LRD' => 'Liberia - LRD',
      'LYD' => 'Libya - LYD',
      'CHF' => 'Liechtenstein - CHF',
      'EUR' => 'Lithuania - EUR',
      'EUR' => 'Luxembourg - EUR',
      'MOP' => 'Macau (China) - MOP',
      'MKD' => 'Macedonia (FYROM) - MKD',
      'MGA' => 'Madagascar - MGA',
      'MWK' => 'Malawi - MWK',
      'MYR' => 'Malaysia - MYR',
      'MVR' => 'Maldives - MVR',
      'XOF' => 'Mali - XOF',
      'EUR' => 'Malta - EUR',
      'USD' => 'Marshall Islands - USD',
      'EUR' => 'Martinique (France) - EUR',
      'MRO' => 'Mauritania - MRO',
      'MUR' => 'Mauritius - MUR',
      'EUR' => 'Mayotte (France) - EUR',
      'MXN' => 'Mexico - MXN',
      'USD' => 'Micronesia - USD',
      'MDL' => 'Moldova - MDL',
      'EUR' => 'Monaco - EUR',
      'MNT' => 'Mongolia - MNT',
      'EUR' => 'Montenegro - EUR',
      'XCD' => 'Montserrat (UK) - XCD',
      'MAD' => 'Morocco - MAD',
      'MZN' => 'Mozambique - MZN',
      'MMK' => 'Myanmar (Burma) - MMK',
      'NAD' => 'Namibia - NAD',
      'AUD' => 'Nauru - AUD',
      'NPR' => 'Nepal - NPR',
      'EUR' => 'Netherlands - EUR',
      'XPF' => 'New Caledonia (France) - XPF',
      'NZD' => 'New Zealand - NZD',
      'NIO' => 'Nicaragua - NIO',
      'XOF' => 'Niger - XOF',
      'NGN' => 'Nigeria - NGN',
      'NZD' => 'Niue (New Zealand) - NZD',
      'AUD' => 'Norfolk Island (Australia) - AUD',
      'USD' => 'Northern Mariana Islands (USA) - USD',
      'KPW' => 'North Korea - KPW',
      'NOK' => 'Norway - NOK',
      'OMR' => 'Oman - OMR',
      'PKR' => 'Pakistan - PKR',
      'USD' => 'Palau - USD',
      'ILS' => 'Palestine - ILS',
      'USD' => 'Panama - USD',
      'PGK' => 'Papua New Guinea - PGK',
      'PYG' => 'Paraguay - PYG',
      'PEN' => 'Peru - PEN',
      'PHP' => 'Philippines - PHP',
      'NZD' => 'Pitcairn Islands (UK) - NZD',
      'PLN' => 'Poland - PLN',
      'EUR' => 'Portugal - EUR',
      'USD' => 'Puerto Rico (USA) - USD',
      'QAR' => 'Qatar - QAR',
      'EUR' => 'Reunion (France) - EUR',
      'RON' => 'Romania - RON',
      'RUB' => 'Russia - RUB',
      'RWF' => 'Rwanda - RWF',
      'USD' => 'Saba (Netherlands) - USD',
      'EUR' => 'Saint Barthelemy (France) - EUR',
      'SHP' => 'Saint Helena (UK) - SHP',
      'XCD' => 'Saint Kitts and Nevis - XCD',
      'XCD' => 'Saint Lucia - XCD',
      'EUR' => 'Saint Martin (France) - EUR',
      'EUR' => 'Saint Pierre and Miquelon (France) - EUR',
      'XCD' => 'Saint Vincent and the Grenadines - XCD',
      'WST' => 'Samoa - WST',
      'EUR' => 'San Marino - EUR',
      'STD' => 'Sao Tome and Principe - STD',
      'SAR' => 'Saudi Arabia - SAR',
      'XOF' => 'Senegal - XOF',
      'RSD' => 'Serbia - RSD',
      'SCR' => 'Seychelles - SCR',
      'SLL' => 'Sierra Leone - SLL',
      'SGD' => 'Singapore - SGD',
      'USD' => 'Sint Eustatius (Netherlands) - USD',
      'ANG' => 'Sint Maarten (Netherlands) - ANG',
      'EUR' => 'Slovakia - EUR',
      'EUR' => 'Slovenia - EUR',
      'SBD' => 'Solomon Islands - SBD',
      'SOS' => 'Somalia - SOS',
      'ZAR' => 'South Africa - ZAR',
      'GBP' => 'South Georgia Island (UK) - GBP',
      'KRW' => 'South Korea - KRW',
      'SSP' => 'South Sudan - SSP',
      'EUR' => 'Spain - EUR',
      'LKR' => 'Sri Lanka - LKR',
      'SDG' => 'Sudan - SDG',
      'SRD' => 'Suriname - SRD',
      'NOK' => 'Svalbard and Jan Mayen (Norway) - NOK',
      'SZL' => 'Swaziland - SZL',
      'SEK' => 'Sweden - SEK',
      'CHF' => 'Switzerland - CHF',
      'SYP' => 'Syria - SYP',
      'TWD' => 'Taiwan - TWD',
      'TJS' => 'Tajikistan - TJS',
      'TZS' => 'Tanzania - TZS',
      'THB' => 'Thailand - THB',
      'USD' => 'Timor-Leste - USD',
      'XOF' => 'Togo - XOF',
      'NZD' => 'Tokelau (New Zealand) - NZD',
      'TOP' => 'Tonga - TOP',
      'TTD' => 'Trinidad and Tobago - TTD',
      'GBP' => 'Tristan da Cunha (UK) - GBP',
      'TND' => 'Tunisia - TND',
      'TRY' => 'Turkey - TRY',
      'TMT' => 'Turkmenistan - TMT',
      'USD' => 'Turks and Caicos Islands (UK) - USD',
      'AUD' => 'Tuvalu - AUD',
      'UGX' => 'Uganda - UGX',
      'UAH' => 'Ukraine - UAH',
      'AED' => 'United Arab Emirates - AED',
      'GBP' => 'United Kingdom - GBP',
      'USD' => 'United States of America - USD',
      'UYU' => 'Uruguay - UYU',
      'USD' => 'US Virgin Islands (USA) - USD',
      'UZS' => 'Uzbekistan - UZS',
      'VUV' => 'Vanuatu - VUV',
      'EUR' => 'Vatican City (Holy See) - EUR',
      'VEF' => 'Venezuela - VEF',
      'VND' => 'Vietnam - VND',
      'USD' => 'Wake Island (USA) - USD',
      'XPF' => 'Wallis and Futuna (France) - XPF',
      'YER' => 'Yemen - YER',
      'ZMW' => 'Zambia - ZMW',
    ];
  }

}
